@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, Partition, StorageConfiguration
+from netbox_storage.models import Filesystem, Drive, Partition, LinuxVolume
 
 
 #
@@ -42,3 +42,16 @@ class NestedPartitionSerializer(WritableNestedSerializer):
     class Meta:
         model = Partition
         fields = ["id", "url", "display", "size", "device", "type"]
+
+
+#
+# Linux Volume
+#
+class NestedLinuxVolumeSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:linuxvolume-detail"
+    )
+
+    class Meta:
+        model = LinuxVolume
+        fields = ["id", "url", "display", "size", "path"]
\ No newline at end of file
