@@ -2,8 +2,8 @@ from rest_framework import serializers
 
 from netbox.api.serializers import NetBoxModelSerializer
 from netbox_storage.api.nested_serializers import NestedFilesystemSerializer, NestedDriveSerializer, \
-    NestedPartitionSerializer
-from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume, StorageConfiguration
+    NestedPartitionSerializer, NestedLinuxVolumeSerializer
+from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume, StorageConfigurationLinuxVolume
 from virtualization.api.nested_serializers import NestedClusterSerializer, NestedVirtualMachineSerializer
 
 
@@ -77,3 +77,19 @@ class LinuxVolumeSerializer(serializers.ModelSerializer):
             "last_updated",
             "custom_fields",
         )
+
+
+class StorageConfigurationLinuxVolumeSerializer(serializers.ModelSerializer):
+    linux_volume = NestedLinuxVolumeSerializer(required=False, allow_null=True)
+    virtual_machine = NestedVirtualMachineSerializer(required=False, allow_null=True)
+
+    class Meta:
+        model = StorageConfigurationLinuxVolume
+        fields = (
+            "id",
+            "virtual_machine",
+            "linux_volume",
+            "created",
+            "last_updated",
+            "custom_fields",
+        )
