@@ -9,8 +9,7 @@ from netbox_storage.api.serializers import (
 )
 from netbox_storage.filters import DriveFilter, FilesystemFilter, \
     PartitionFilter, LinuxVolumeFilter
-from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume, \
-    StorageConfiguration
+from netbox_storage.models import Drive, Filesystem, Partition, LinuxVolume
 
 
 class NetboxStorageRootView(APIRootView):
