@@ -9,7 +9,7 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
-    StorageConfiguration
+    StorageConfigurationLinuxVolume, LinuxVolume
 from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
@@ -88,7 +88,7 @@ class LVMSimpleForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = StorageConfiguration
+        model = StorageConfigurationLinuxVolume
         exclude = (
             "cluster_type",
             "vg_name",
@@ -191,26 +191,22 @@ class LinuxVolumeSimpleForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = StorageConfiguration
+        model = StorageConfigurationLinuxVolume
         fields = [
             "virtual_machine",
         ]
 
     def save(self, *args, **kwargs):
-        storage_configuration = super().save(*args, **kwargs)
 
         drive = Drive.objects.create(cluster=self.cleaned_data['cluster'], size=self.cleaned_data['size'])
         partition = Partition.objects.create(drive=drive, device=drive.device_name(), size=self.cleaned_data['size'],
-                                             type='Linux LVM', description='Partition 1 on SSD Cluster')
-        volumegroup = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        physicalvolume = PhysicalVolume.objects.create(partition=partition, pv_name=drive.device_name(), vg=volumegroup)
-        logicalvolume = LogicalVolume.objects.create(vg=volumegroup,
-                                                     lv_name=self.cleaned_data['lv_name'],
-                                                     size=self.cleaned_data['size'],
-                                                     path=self.cleaned_data['path'],
-                                                     fs=self.cleaned_data['fs'])
-        print(f"{self.cleaned_data['lv_name']}")
-        print(f"{self.cleaned_data['vg_name']}")
+                                             type='Linux', description='Partition 1 on SSD Cluster')
+        linux_volume = LinuxVolume.objects.create(partition=partition, size=self.cleaned_data['size'],
+                                                  path=self.cleaned_data['path'], fs=self.cleaned_data['fs'],
+                                                  description='Linux volume',)
+        self.instance.linux_volume = linux_volume
+        storage_configuration = super().save(*args, **kwargs)
+
         print(f"{self.cleaned_data['size']}")
         print(f"{self.cleaned_data['path']}")
         print(f"{self.cleaned_data['fs']}")
@@ -218,11 +214,10 @@ class LinuxVolumeSimpleForm(NetBoxModelForm):
         print("Instances")
         print(drive)
         print(partition)
-        print(volumegroup)
-        print(physicalvolume)
-        print(logicalvolume)
+        print(linux_volume)
+        print(storage_configuration)
 
-        return drive
+        return storage_configuration
 
 
 class VolumeSimpleForm(NetBoxModelForm):
