@@ -6,26 +6,6 @@ class Migration(migrations.Migration):
     initial = True
 
     operations = [
-        migrations.CreateModel(
-            name="StorageConfiguration",
-            fields=[
-                ("created", models.DateTimeField(auto_now_add=True, null=True)),
-                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
-                (
-                    "custom_field_data",
-                    models.JSONField(
-                        blank=True,
-                        default=dict,
-                        encoder=utilities.json.CustomFieldJSONEncoder
-                    ),
-                ),
-                ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("virtual_machine",
-                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name="virtual_machine_storage_configuration",
-                                   to="virtualization.virtualmachine")),
-            ],
-        ),
         migrations.CreateModel(
             name="Drive",
             fields=[
@@ -203,4 +183,28 @@ class Migration(migrations.Migration):
                 "ordering": ("path", "fs", "id"),
             },
         ),
+        migrations.CreateModel(
+            name="StorageConfigurationLinuxVolume",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("virtual_machine",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name="virtual_machine_storage_configuration",
+                                   to="virtualization.virtualmachine")),
+                ("linux_volume",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name='linux_volume_storage_configuration',
+                                   to='netbox_storage.linuxvolume')),
+            ],
+        ),
     ]
