@@ -6,26 +6,6 @@ from django.urls import reverse
 from netbox.models import NetBoxModel
 
 
-class StorageConfiguration(NetBoxModel):
-    virtual_machine = models.ForeignKey(
-        to='virtualization.VirtualMachine',
-        on_delete=models.CASCADE,
-        related_name='virtual_machine_storage_configuration',
-    )
-
-    clone_fields = [
-        "virtual_machine"
-    ]
-
-    class Meta:
-        ordering = ["virtual_machine"]
-
-    def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
-
-    def __str__(self):
-        return f"Storage Configuration of the VM {self.virtual_machine}"
-
 
 class Drive(NetBoxModel):
     cluster = models.ForeignKey(
@@ -345,3 +325,30 @@ class LinuxVolume(NetBoxModel):
 
     class Meta:
         ordering = ("size", "path", "description")
+
+
+class StorageConfigurationLinuxVolume(NetBoxModel):
+    virtual_machine = models.ForeignKey(
+        to='virtualization.VirtualMachine',
+        on_delete=models.CASCADE,
+        related_name='virtual_machine_storage_configuration',
+    )
+    linux_volume = models.ForeignKey(
+        LinuxVolume,
+        on_delete=models.CASCADE,
+        related_name='linux_volume_storage_configuration'
+    )
+
+    clone_fields = [
+        "virtual_machine",
+        "linux_volume"
+    ]
+
+    class Meta:
+        ordering = ["virtual_machine", "linux_volume"]
+
+    #def get_absolute_url(self):
+    #    return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return f"Storage Configuration of the VM {self.virtual_machine}"
