@@ -1,7 +1,7 @@
 import logging
 
 from extras.plugins import PluginTemplateExtension
-from netbox_storage.models import PhysicalVolume, LogicalVolume, LinuxVolume
+from netbox_storage.models import PhysicalVolume, LogicalVolume, LinuxVolume, StorageConfigurationLinuxVolume
 
 
 class LVMModel:
@@ -57,6 +57,8 @@ class RelatedDrives(PluginTemplateExtension):
 
         lv = LogicalVolume.objects.all()
 
+        storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
+
         platform = obj.platform
         if platform is not None:
             if platform.name.lower().__contains__('windows'):
@@ -80,7 +82,8 @@ class RelatedDrives(PluginTemplateExtension):
             return self.render(
                 "netbox_storage/inc/unknown_os_box.html",
                 extra_context={
-                    "lv": lv
+                    "lv": lv,
+                    "storage_configuration": storage_configuration
                 }
             )
 
